@@ -5,7 +5,7 @@ use base 'PDF::API2::Outline';
 use strict;
 use warnings;
 
-our $VERSION = '2.041'; # VERSION
+our $VERSION = '2.042'; # VERSION
 
 use PDF::API2::Basic::PDF::Utils;
 
@@ -17,4 +17,9 @@ sub new {
     return $self;
 }
 
+sub count {
+    my $self = shift();
+    return abs($self->SUPER::count());
+}
+
 1;
